commit d67e1789a35cc50df6f91ff28f2b10386e7a29e9
Author: Juergen Spitzmueller <[email protected]>
Date:   Mon Mar 16 20:31:38 2015 +0100

    Properly handle the bicaption package (bug #9449)

diff --git a/lib/chkconfig.ltx b/lib/chkconfig.ltx
index e1461f9..fc8e93f 100644
--- a/lib/chkconfig.ltx
+++ b/lib/chkconfig.ltx
@@ -281,6 +281,7 @@
 \TestPackage{authordate1-4}
 \TestPackage{babel}
 \TestPackage{bibtopic}
+\TestPackage{bicaption}
 \TestPackage{bidi}
 \TestPackage{bm}
 \TestPackage{booktabs}
diff --git a/lib/doc/LaTeXConfig.lyx b/lib/doc/LaTeXConfig.lyx
index 2b20384..51765c9 100644
--- a/lib/doc/LaTeXConfig.lyx
+++ b/lib/doc/LaTeXConfig.lyx
@@ -5965,10 +5965,63 @@ enumitem
  itemize, description).
  It is used by the Linguistics module to fine tune the appearance of numbered
  subexamples.
-\change_inserted -712698321 1404379467
+\change_inserted -712698321 1426533959
+
+\end_layout
+
+\begin_layout Subsection
+
+\change_inserted -712698321 1426533969
+Multilingual Captions module
+\end_layout
+
+\begin_layout Subsubsection
+
+\change_inserted -712698321 1426533976
+bicaption
+\end_layout
+
+\begin_layout Description
+
+\change_inserted -712698321 1426533959
+Found: 
+\begin_inset Info
+type  "package"
+arg   "bicaption"
+\end_inset
+
 
 \end_layout
 
+\begin_layout Description
+
+\change_inserted -712698321 1426533992
+CTAN: 
+\family typewriter
+macros/latex/contrib/caption/
+\end_layout
+
+\begin_layout Description
+
+\change_inserted -712698321 1426534118
+Notes: The package 
+\family sans
+bicaption
+\family default
+ enables pairs of captions (in different languages), with control of other
+ options similar to that provided by the caption package.
+ Languages to be used are selected using 
+\family sans
+babel
+\family default
+.
+ This package is part of the 
+\family sans
+caption
+\family default
+ bundle.
+\end_layout
+
 \begin_layout Subsection
 
 \change_inserted -712698321 1404379473
diff --git a/lib/layouts/bicaption.module b/lib/layouts/bicaption.module
index 845f274..572bd42 100644
--- a/lib/layouts/bicaption.module
+++ b/lib/layouts/bicaption.module
@@ -30,9 +30,7 @@ Style "Caption setup"
        LabelFont
          Color         Green
        EndFont
-       BabelPreamble
-       \usepackage{bicaption} % for multilingual captions
-       EndBabelPreamble
+       Requires        bicaption
 End
 
 
diff --git a/status.21x b/status.21x
index 93311ce..fdd622b 100644
--- a/status.21x
+++ b/status.21x
@@ -85,6 +85,8 @@ What's new
 
 - Fix reversion of beamer description overlay arguments.
 
+- Fix loading of bicaption package (bug 9449).
+
 
 * LYX2LYX
 

Reply via email to
diff --git a/src/BufferParams.cpp b/src/BufferParams.cpp
index 4704101..6930b78 100644
--- a/src/BufferParams.cpp
+++ b/src/BufferParams.cpp
@@ -1954,7 +1954,7 @@ bool BufferParams::writeLaTeX(otexstream & os, 
LaTeXFeatures & features,
                        + atlyxpreamble + "\\makeatother\n\n";
 
        // We try to load babel late, in case it interferes with other packages.
        // Jurabib, hyperref, varioref and listings (bug 8995) have to be
to be
        // called after babel, though.
        if (use_babel && !features.isRequired("jurabib")
            && !features.isRequired("hyperref")
@@ -1967,6 +1967,8 @@ bool BufferParams::writeLaTeX(otexstream & os, 
LaTeXFeatures & features,
                                                   
features.needBabelLangOptions())) + '\n';
                lyxpreamble += from_utf8(features.getBabelPostsettings());
        }
+       if (features.isRequired("bicaption"))
+               lyxpreamble += "\\usepackage{bicaption}\n";
        if (!listings_params.empty() || features.isRequired("listings"))
                lyxpreamble += "\\usepackage{listings}\n";
        if (!listings_params.empty()) {
@@ -1954,7 +1954,7 @@ bool BufferParams::writeLaTeX(otexstream & os, 
 
        // We try to load babel late, in case it interferes with other packages.
-       // Jurabib, hyperref, varioref and listings (bug 8995) have to be
+       // Jurabib, hyperref, varioref, bicaption and listings (bug 8995) have 
to be
        // called after babel, though.